==> axyl-lucene_2.1.3.tar.gz: axyl-lucene-2.1.3/luceneserver/src/nz/net/catalyst/lucene/server/TransmissionException.java <==
/** *********************************************************************
 * Copyright (C) 2003 Catalyst IT                                       *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to:                           *
 *   The Free Software Foundation, Inc., 59 Temple Place, Suite 330,    *
 *   Boston, MA  02111-1307  USA                                        *
 ************************************************************************/
package nz.net.catalyst.lucene.server;

import nz.net.catalyst.RtException;

public class TransmissionException extends RtException
{
  public TransmissionException()
  {
    super();
  }

  public TransmissionException(String message)
  {
    super(message);
  }

  public TransmissionException(String message, Throwable exception)
  {
    super(message, exception);
  }
  public TransmissionException(Throwable exception)
  {
    super(exception);
  }
}

==> axyl-lucene_2.3.0.tar.gz: axyl-lucene-2.3.0/luceneserver/src/nz/net/catalyst/lucene/server/TransmissionException.java <==
/** *********************************************************************
 * Copyright (C) 2003 Catalyst IT                                       *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to:                           *
 *   The Free Software Foundation, Inc., 59 Temple Place, Suite 330,    *
 *   Boston, MA  02111-1307  USA                                        *
 ************************************************************************/
package nz.net.catalyst.lucene.server;

public class TransmissionException extends RuntimeException
{
  // Unique SerialVersionUID (should NEVER change)
  static final long serialVersionUID = 0L;
    
  public TransmissionException()
  {
    super();
  }

  public TransmissionException(String message)
  {
    super(message);
  }

  public TransmissionException(String message, Throwable exception)
  {
    super(message, exception);
  }
  public TransmissionException(Throwable exception)
  {
    super(exception);
  }
}
